/**************************************************************************

    This file is part of xclass, a Win95-looking GUI toolkit.
    Copyright (C) 1996, 1997 David Barth, Hector Peraza.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

**************************************************************************/

#ifndef __VERSION_H
#define __VERSION_H


#define XCLASS_MAJOR_VERSION  "0"
#define XCLASS_MINOR_VERSION  "8"
#define XCLASS_PATCH_LEVEL    "3"
#define XCLASS_VERSION        "0.8.3"
#define XCLASS_RELEASE_DATE   "5-Jul-2004"


#endif  // __VERSION_H
